pywurfl.serialize

Package pywurfl :: Module serialize |
[hide private]
[frames] | no frames]

# Module serialize

source code
pywurfl WURFL class hierarchy serializer

Author: Armand Lynch <lyncha@users.sourceforge.net>

Copyright: Copyright 2006-2008, Armand Lynch

License: LGPL

Classes | [hide private]
| Serialize

Variables | [hide private]
| __doc__ = ``...``
| __url__ = ``'``http://celljam.net/``'``

Variables Details | [hide private]

  ### __doc__ Value:
      """
      pywurfl WURFL class hierarchy serializer
      """